// 商品相关
import { request } from "@/lib/service"
import { baseUrl } from '@/config'

/**
 * @desc 商品+店铺集合+店铺搜索接口
 * @param { Object } params so many key, see the api docs
 *  {
		page 当前页码
		pagenum 每页条数
		sort 排序：1综合优先 2销量优先 3价格升序 4价格降序 5推荐 6离我最近
		city 城市ID
		keywords 关键字
		cat_id 分类ID 0默认全部
		...
	}
 */
export function searchGoods(params) {
	return request({
		url: `${baseUrl}/wxxcx/searchGoodsXcx.htm`,
		method: 'post',
		data: params
	})
}


/**
 * @desc 商品详情
 * @param { goods_id } 商品ID
 * @param { shop_id } 当前店铺ID（分销功能使用）
 * @param { agent_id } 代理商ID（分销功能使用）
 */
export function goodDetail(params) {
	return request({
		url: `${baseUrl}/wxxcx/goodsDetail.htm`,
		method: 'post',
		data: params
	})
}

/**
 * @desc 商品规格选择接口
 * goods_id
 * shop_id
 * sale_type
 */
export function goodsSku(goods_id, shop_id, sale_type = 0) {
	return request({
		url: `${baseUrl}/wxxcx/goodsSku.htm`,
		method: 'post',
		data: {
			goods_id, shop_id, sale_type
		}
	})
}
