// 用户相关
import { request } from "@/lib/service"
import { baseUrl } from '@/config' // 将请求的baseUrl写这里，为了开发时调试请求地址
const RSA = require('@/utils/wx_rsa.js')
import { publicKey } from '@/config/index.js'

/**
 * @desc 检查登录态
 */
export function checkLoginStatus() {
	return request({
		url: `${baseUrl}/wxxcx/isLogin.htm`,
		method: 'post',
		needMask: true
	})
}

/**
 * 检查服务器时间
 */
export function checkLoginTime() {
	return request({
		url: `${baseUrl}/wxxcx/getFwqTime.htm`,
		method: 'post'
	})
}

/**
 * @desc 微信登录 wx.login 获取openid unionid等信息
 * @param { String } code  
 */
export function wxLogin(code) {
	return request({
		url: `${baseUrl}/wxxcx/getInfo.htm`,
		data: {
			js_code: code
		}
	})
}

/**
 * @desc 静默登录
 * @param { Number } userPhone
 * @param { String } time
 */
export function slelentLogin(userPhone, time) {
	const encrypt_rsa = RSA.KEYUTIL.getKey(publicKey)
	return request({
		url: `${baseUrl}/wxxcx/silentLogin.htm`,
		method: 'post',
		data: {
			un: RSA.hex2b64(encrypt_rsa.encrypt(userPhone)),
			tm: RSA.hex2b64(encrypt_rsa.encrypt(time))
		}
	})
}

/**
 * @desc 退出登录
 */
export function logout() {
	return request({
		url: `${baseUrl}/wxxcx/loginOut.htm`,
		method: 'post',
		needMask: true
	})
}

/**
 * @desc 注册
 * @param {Object} params
 * 
 * lgtype 必填 登录方式：1微信登录 2短信验证码登录 3账号密码登录
 * user 用户名（lgtype!=1时必填）
 * pwd 登录密码（lgtype=3时必填）
 * yzm 登录验证码（lgtype=2时必填
 * encryptedData 加密信息（lgtype=1时必填）
 * iv 加密算法的初始向量（lgtype=1时必填）
 * session_key 会话密钥（lgtype=1时必填）
 */
export function register(params) {
	return request({
		url: `${baseUrl}/wxxcx/login.htm`,
		method: 'post',
		data: params
	})
}




/**
 * @desc 获取手机验证码
 */
export function smsCode() {
	return request({
		url:`${baseUrl}/a`
	})
}